@@ -25,7 +25,12 @@ import bzrlib
 import bzrlib.api
 from bzrlib.commands import plugin_cmds
 
-version_info = (0, 4, 4, 'final', 0)
+from info import (
+    bzr_commands,
+    bzr_plugin_version as version_info,
+    bzr_compatible_versions,
+    )
+
 if version_info[3] == 'final':
     version_string = '%d.%d.%d' % version_info[:3]
 else:
@@ -33,16 +38,15 @@ else:
 __version__ = version_string
 __author__ = 'Jelmer Vernooij <jelmer@samba.org>'
 
-COMPATIBLE_BZR_VERSIONS = [(1, 6, 0), (1, 7, 0), (1, 8, 0), (1, 9, 0),
-                           (1, 10, 0), (1, 11, 0), (1, 12, 0), (1, 13, 0)]
+bzrlib.api.require_any_api(bzrlib, bzr_compatible_versions)
 
-bzrlib.api.require_any_api(bzrlib, COMPATIBLE_BZR_VERSIONS)
-
-for cmd in ["replay", "rebase", "rebase_abort", "rebase_continue",
-            "rebase_todo"]:
+for cmd in bzr_commands:
     plugin_cmds.register_lazy("cmd_%s" % cmd, [], 
         "bzrlib.plugins.rebase.commands")
 
+plugin_cmds.register_lazy('cmd_foreign_mapping_upgrade', ['svn-upgrade'], 
+                          'bzrlib.plugins.rebase.commands')
+
 
 def test_suite():
     """Determine the testsuite for bzr-rebase."""
@@ -51,7 +55,11 @@ def test_suite():
 
     loader = TestUtil.TestLoader()
     suite = TestSuite()
-    testmod_names = ['test_blackbox', 'test_rebase', 'test_maptree']
+    testmod_names = [
+        'test_blackbox',
+        'test_maptree',
+        'test_rebase',
+        'test_upgrade']
     suite.addTest(loader.loadTestsFromModuleNames(
                               ["%s.%s" % (__name__, i) for i in testmod_names]))
 
