@@ -15,20 +15,32 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """Rebase."""
 
+import os
+
+from bzrlib import (
+    osutils,
+    )
 from bzrlib.config import Config
-from bzrlib.errors import (BzrError, NoSuchFile, UnknownFormatError,
-                           NoCommonAncestor, NoSuchId, UnrelatedBranches)
+from bzrlib.errors import (
+    BzrError,
+    NoSuchFile,
+    UnknownFormatError,
+    NoCommonAncestor,
+    NoSuchId,
+    UnrelatedBranches,
+    )
 from bzrlib.generate_ids import gen_revision_id
 from bzrlib.graph import FrozenHeadsCache
 from bzrlib.merge import Merger
-from bzrlib import osutils
 from bzrlib.revision import NULL_REVISION
 from bzrlib.trace import mutter
 from bzrlib.tsort import topo_sort
 import bzrlib.ui as ui
 
-from maptree import MapTree, map_file_ids
-import os
+from bzrlib.plugins.rebase.maptree import (
+    MapTree,
+    map_file_ids,
+    )
 
 REBASE_PLAN_FILENAME = 'rebase-plan'
 REBASE_CURRENT_REVID_FILENAME = 'rebase-current'
@@ -394,12 +406,22 @@ def commit_rebase(wt, oldrev, newrevid):
     revprops = dict(oldrev.properties)
     revprops[REVPROP_REBASE_OF] = oldrev.revision_id
     committer = wt.branch.get_config().username()
-    author = oldrev.get_apparent_author()
-    if author == committer or 'author' in revprops:
-        author = None
+    authors = oldrev.get_apparent_authors()
+    if oldrev.committer == committer:
+        # No need to explicitly record the authors if the original 
+        # committer is rebasing.
+        if [oldrev.committer] == authors:
+            authors = None
+    else:
+        if not oldrev.committer in authors:
+            authors.append(oldrev.committer)
+    if 'author' in revprops:
+        del revprops['author']
+    if 'authors' in revprops:
+        del revprops['authors']
     wt.commit(message=oldrev.message, timestamp=oldrev.timestamp, 
               timezone=oldrev.timezone, revprops=revprops, rev_id=newrevid,
-              committer=committer, author=author)
+              committer=committer, authors=authors)
     write_active_rebase_revid(wt, None)
 
 
@@ -522,7 +544,7 @@ def complete_revert(wt, newparents):
     newtree = wt.branch.repository.revision_tree(newparents[0])
     delta = wt.changes_from(newtree)
     wt.branch.generate_revision_history(newparents[0])
-    wt.set_parent_ids(newparents[:1])
+    wt.set_parent_ids([r for r in newparents[:1] if r != NULL_REVISION])
     for (f, _, _) in delta.added:
         abs_path = wt.abspath(f)
         if osutils.lexists(abs_path):
@@ -532,16 +554,16 @@ def complete_revert(wt, newparents):
                 os.unlink(abs_path)
     wt.revert(None, old_tree=newtree, backups=False)
     assert not wt.changes_from(wt.basis_tree()).has_changed(), "Rev changed"
-    wt.set_parent_ids(newparents)
+    wt.set_parent_ids([r for r in newparents if r != NULL_REVISION])
 
 
 class ReplaySnapshotError(BzrError):
     """Raised when replaying a snapshot failed."""
-    _fmt = """Replaying the snapshot failed: %(message)s."""
+    _fmt = """Replaying the snapshot failed: %(msg)s."""
 
-    def __init__(self, message):
+    def __init__(self, msg):
         BzrError.__init__(self)
-        self.message = message
+        self.msg = msg
 
 
 class ReplayParentsInconsistent(BzrError):
