@@ -22,19 +22,32 @@ from bzrlib.revision import NULL_REVISION
 from bzrlib.tests import TestCase, TestCaseWithTransport
 from bzrlib.trace import mutter
 
-from rebase import (marshall_rebase_plan, unmarshall_rebase_plan, 
-                    replay_snapshot, generate_simple_plan,
-                    generate_transpose_plan, rebase_plan_exists,
-                    rebase_todo, REBASE_PLAN_FILENAME, 
-                    REBASE_CURRENT_REVID_FILENAME, read_rebase_plan, 
-                    remove_rebase_plan, read_active_rebase_revid, 
-                    write_active_rebase_revid, write_rebase_plan, MapTree,
-                    ReplaySnapshotError, ReplayParentsInconsistent, 
-                    replay_delta_workingtree, replay_determine_base, 
-                    commit_rebase)
+from bzrlib.plugins.rebase.rebase import (
+    marshall_rebase_plan,
+    unmarshall_rebase_plan,
+    replay_snapshot,
+    generate_simple_plan,
+    generate_transpose_plan,
+    rebase_plan_exists,
+    rebase_todo,
+    REBASE_PLAN_FILENAME,
+    REBASE_CURRENT_REVID_FILENAME,
+    read_rebase_plan,
+    remove_rebase_plan,
+    read_active_rebase_revid,
+    write_active_rebase_revid,
+    write_rebase_plan,
+    MapTree,
+    ReplaySnapshotError,
+    ReplayParentsInconsistent,
+    replay_delta_workingtree,
+    replay_determine_base,
+    commit_rebase,
+    )
 
 
 class RebasePlanReadWriterTests(TestCase):
+
     def test_simple_marshall_rebase_plan(self):
         self.assertEqualDiff(
 """# Bazaar rebase plan 1
@@ -60,6 +73,7 @@ oldrev newrev newparent1 newparent2
 
 
 class ConversionTests(TestCaseWithTransport):
+
     def test_simple(self):
         wt = self.make_branch_and_tree('.')
         b = wt.branch
@@ -239,6 +253,7 @@ class PlanCreatorTests(TestCaseWithTransport):
  
 
 class PlanFileTests(TestCaseWithTransport):
+
    def test_rebase_plan_exists_false(self):
         wt = self.make_branch_and_tree('.')
         self.assertFalse(rebase_plan_exists(wt))
@@ -297,6 +312,7 @@ oldrev newrev newparent1 newparent2
 
 
 class CurrentRevidFileTests(TestCaseWithTransport):
+
     def test_read_nonexistant(self):
         wt = self.make_branch_and_tree('.')
         self.assertIs(None, read_active_rebase_revid(wt))
@@ -323,6 +339,7 @@ class CurrentRevidFileTests(TestCaseWithTransport):
 
 
 class RebaseTodoTests(TestCase):
+
     def test_done(self):
         class Repository:
             def has_revision(self, revid):
@@ -655,7 +672,9 @@ class TestReplayParentsInconsistent(TestCase):
 
 
 class ReplayDetermineBaseTests(TestCase):
+
     def setUp(self):
+        TestCase.setUp(self)
         self.graph = Graph(self)
 
     def get_parent_map(self, keys):
